@@ -32,12 +32,14 @@ import org.glom.libglom.LayoutFieldVector;
 import org.glom.libglom.LayoutGroup;
 import org.glom.libglom.LayoutGroupVector;
 import org.glom.libglom.LayoutItem;
+import org.glom.libglom.LayoutItem_GroupBy;
 import org.glom.libglom.LayoutItemVector;
 import org.glom.libglom.LayoutItem_Field;
 import org.glom.libglom.LayoutItem_Notebook;
 import org.glom.libglom.LayoutItem_Portal;
 import org.glom.libglom.NumericFormat;
 import org.glom.libglom.Relationship;
+import org.glom.libglom.Report;
 import org.glom.libglom.SortClause;
 import org.glom.libglom.SortFieldPair;
 import org.glom.libglom.StringVector;
@@ -296,6 +298,44 @@ public class DocumentTest {
 
 	}
 
+	@Test
+	public void testReadReportNames() {
+		StringVector reportNames = document.get_report_names("albums");
+		assertEquals(1, reportNames.size()); //TODO: Test something with more reports.
+
+		String reports = reportNames.get(0);
+		for (int i = 1; i < reportNames.size(); i++) {
+			reports += ", " + reportNames.get(i);
+		}
+		assertThat(reports, is("albums_by_artist"));
+	}
+
+	@Test
+	public void testReadReportStructure() {
+		Report report = document.get_report("albums", "albums_by_artist");
+		assertTrue(report != null);
+		LayoutGroup layoutGroup = report.get_layout_group();
+		assertTrue(layoutGroup != null);
+		LayoutItemVector layoutItems = layoutGroup.get_items();
+		final int numItems = safeLongToInt(layoutItems.size());
+		assertEquals(1, numItems);
+
+		LayoutItem layoutItem = layoutItems.get(0);
+		assertTrue(layoutItem != null);
+		LayoutGroup asGroup = LayoutGroup.cast_dynamic(layoutItem);
+		assertTrue(asGroup != null);
+		LayoutItem_GroupBy groupby = LayoutItem_GroupBy.cast_dynamic(layoutItem);
+		assertTrue(groupby != null);
+
+		assertTrue(groupby.get_has_field_group_by());
+		LayoutItem_Field fieldGroupBy = groupby.get_field_group_by();
+		assertTrue(fieldGroupBy != null);
+		assertThat(fieldGroupBy.get_name(), is("artist_id"));
+
+		LayoutGroup groupSecondaries = groupby.get_group_secondary_fields();
+		assertTrue(groupSecondaries != null);
+	}
+
 	// Test thread class that runs all the tests.
 	private class TestThread implements Runnable {
 
